/**
 * This software is contributed or developed by KYOCERA Corporation.
 * (C) 2019 KYOCERA Corporation
 */

package org.chromium.base;

import android.app.AlertDialog;
import android.content.Context;
import android.content.res.Resources;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.widget.DatePicker;
import android.widget.TimePicker;

import jp.kyocera.kcfp.util.KCfpDialogUtil;
import jp.kyocera.kcfp.util.KCfpSoftkeyGuide;
import jp.kyocera.kcfp.util.KCfpWidgetUtil;

public class AfpUiInterfaceWrapper {
    private static final String TAG = "AfpUiInterfaceWrapper";

    private Context mContext;

    public AfpUiInterfaceWrapper(Context context) {
        mContext = context;
    }

    // Reflection for KCfpSoftkeyGuide
    public static final int INDEX_CSK    = 0;
    public static final int INDEX_SK1    = 1;
    public static final int INDEX_SK2    = 2;
    public static final int INDEX_SK3    = 3;
    public static final int INDEX_SK4    = 4;

    public static final String SET_BRANK_STR = "SET_BRANK";
    public static final int LOCAL_RES_ID_NONE  = -1;

    public void setDialogSoftkey(AlertDialog dialog, String resIdStr, int localResId, int position) {
        if ((resIdStr == null || resIdStr.isEmpty()) && localResId <= 0) {
            Log.e(TAG, "setDialogSoftkey Invalid parameters.");
            return;
        }

        KCfpSoftkeyGuide softguide;
        try {
            softguide = KCfpSoftkeyGuide.getSoftkeyGuide(dialog.getWindow());
        } catch (Throwable e) {
            Log.e(TAG, "setDialogSoftkey()", e);
            return;
        }

        String str = "";
        if (!SET_BRANK_STR.equals(resIdStr)) {
            try {
                if (localResId > 0) {
                    str = mContext.getString(localResId);
                } else {
                    int resId = Resources.getSystem().getIdentifier(resIdStr, "string", "android");
                    str = Resources.getSystem().getString(resId);
                }
            } catch (Resources.NotFoundException e) {
                Log.e(TAG, "setDialogSoftkey ResourcesNotFoundException", e);
                str = "";
            }
        }

        try {
            softguide.setText(position, str);
            softguide.invalidate();
        } catch (Throwable e) {
            Log.e(TAG, "setDialogSoftkey()", e);
            return;
        }
    }

    public void assignButtonToSoftkey(AlertDialog dialog, boolean assign) {
        try {
            KCfpDialogUtil.getInstance().assignButtonToSoftkey(dialog, assign);
        } catch (Throwable e) {
            Log.e(TAG, "assignButtonToSoftkey()", e);
        }
    }

    public void setDatePickerNextRightView(DatePicker picker, View view) {
        try {
            KCfpWidgetUtil.getInstance().setDatePickerNextRightView(picker, view);
        } catch (Throwable e) {
            Log.e(TAG, "setDatePickerNextRightView()", e);
        }
    }

    public void setTimePickerNextLeftView(TimePicker picker, View view) {
        try {
            KCfpWidgetUtil.getInstance().setTimePickerNextLeftView(picker, view);
        } catch (Throwable e) {
            Log.e(TAG, "setTimePickerNextLeftView()", e);
        }
    }

    public String getSystemString(String resIdStr) {
        String str = "";
        if (resIdStr.isEmpty()) return str;

        try {
            int resId = Resources.getSystem().getIdentifier(resIdStr, "string", "android");
            str = Resources.getSystem().getString(resId);
        } catch (Resources.NotFoundException e) {
            Log.e(TAG, "getSystemString ResourcesNotFoundException", e);
        }

        return str;
    }
}
